import greenfoot.*; // (World, Actor, GreenfootImage, and Greenfoot)

/**
 * Two times parallel tetris
 * 
 * @author Ulf Erben (based on Dietrich Boles - Tetris )
 * @version 1.0 (06.2013)
 * 
 */
public class DuoTetrisWorld extends World {


    final int PLAYFIELDSTART=0;
    
    final int PLAYFIELDEND=10;
    
    final int PLAYFIELDSTART1=14;
    
    final int PLAYFIELDEND1=24;

    private final int SPEED_INIT=27;
    
    private final int SPEEDUP_INTERVAL=30;

    private static DuoTetrisWorld world = null;

    private Points pointView;

    private Tetromino currentTetromino;
    private Tetromino1 currentTetromino1;
    

//    private Tetromino1 currentTetromino1;
    
    private int speedUpCounter;    
    private int numberOfTetrominos;    
    private int numberOfTetrominos1;    
   
    private int speed;
    
    private int[] list;
    
    public boolean gameOverFlag = false;
    public boolean gameOverFlag1 = false;
    
    private FirstPage firstPage;


    /**
     * Creates a DuoTetris world
     */
    public DuoTetrisWorld() {
        super(28, 24 + 2, 20);

        world = this;
        
        firstPage=new FirstPage();
        addObject(firstPage,13,12);
    }

    // called by firstPage act()    
    void initWorld (){
        
        removeObject(firstPage);
        setBackground("playfield_back.png");
             

        for (int i = 0; i < 28; i++) {
            addObject(new Images(10), i, 24);
            addObject(new Images(11), i, 24 + 1); 
        }

        for (int i = 0; i < 24; i++) {
            addObject(new Images(11), PLAYFIELDEND,i); 
            addObject(new Images(11), PLAYFIELDEND+1,i); 
            addObject(new Images(11), PLAYFIELDEND+2,i); 
            addObject(new Images(11), PLAYFIELDEND+3,i); 
        
            addObject(new Images(11), PLAYFIELDEND1,i); 
            addObject(new Images(11), PLAYFIELDEND1+1,i); 
            addObject(new Images(11), PLAYFIELDEND1+2,i); 
            addObject(new Images(11), PLAYFIELDEND1+3,i); 
        }
        this.pointView = new Points();

        list = new int[1000];
        for (int i=0;i<1000;i++){
            list[i]=(int) (Math.random() * 7);
        }
        
        this.speed = SPEED_INIT;
        Greenfoot.setSpeed(this.speed);
        this.numberOfTetrominos = 0;
        this.numberOfTetrominos1 = 0;
        this.speedUpCounter = 0;        
        
        currentTetromino = genTetromino();
        currentTetromino1 = genTetromino1();
             
    }    
    
    // returns the current world
    static DuoTetrisWorld getWorld() {
        return world;
    }

    // returns the current tetromino or null if game terminated
    Tetromino getCurrentTetromino() {
        return currentTetromino;
    }

    // changes the current tetromino
    void setCurrentTetromino(Tetromino t) {
        currentTetromino = t;
    }

    Tetromino genTetromino() {
        numberOfTetrominos +=1;
        speedUpCounter +=1;
        
        if (speedUpCounter > SPEEDUP_INTERVAL){
           speed=speed + 1;
           Greenfoot.setSpeed(speed);
           speedUpCounter = 0;
        }
        
        if (numberOfTetrominos==998)
          numberOfTetrominos=0;

            addObject(new Images(7), 11, 3);
            addObject(new Images(list[numberOfTetrominos+1]), 11, 3);
        
        switch (list[numberOfTetrominos]) {
        case 0:
            return new ITetromino();
        case 1:
            return new JTetromino();
        case 2:
            return new LTetromino();
        case 3:
            return new OTetromino();
        case 4:
            return new TTetromino();
        case 5:
            return new STetromino();
        default: // 6
            return new ZTetromino();
        }
    }

    // adds new points to the point view
    void newPoints(int rows) {
        int p = 0;
        switch (rows) {
        case 1:
            p = 10;
            break;
        case 2:
            p = 30;
            break;
        case 3:
            p = 60;
            break;
        case 4:
            p = 100;
            break;
        }
        pointView.add(p);
    }

    // returns the current points of the player
    int getPoints() {
        return pointView.getPoints();
    }
    
    
    // SECOND Tetris
   Tetromino1 getCurrentTetromino1() {
       return currentTetromino1;
   }

    // changes the current tetromino
   void setCurrentTetromino1(Tetromino1 t) {
       currentTetromino1 = t;
   }

    // creates randomly a new tetromino
    Tetromino1 genTetromino1() {
        numberOfTetrominos1 +=1;
        if (gameOverFlag == true){
        speedUpCounter +=1;
        
           if (speedUpCounter > SPEEDUP_INTERVAL){
             speed=speed + 1;
             Greenfoot.setSpeed(speed);
             speedUpCounter = 0;
           }
        }
        if (numberOfTetrominos1==998)
          numberOfTetrominos1=0;

            addObject(new Images(7), 25, 3);
            addObject(new Images(list[numberOfTetrominos1+1]), 25, 3);
        
        switch (list[numberOfTetrominos1]) {
        case 0:
            return new ITetromino1();
        case 1:
            return new JTetromino1();
        case 2:
            return new LTetromino1();
        case 3:
            return new OTetromino1();
        case 4:
            return new TTetromino1();
        case 5:
            return new STetromino1();
        default: // 6
            return new ZTetromino1();
        }
    }

    // adds new points to the point view
    void newPoints1(int rows) {
        int p = 0;
        switch (rows) {
        case 1:
            p = 10;
            break;
        case 2:
            p = 30;
            break;
        case 3:
            p = 60;
            break;
        case 4:
            p = 100;
            break;
        }
        pointView.add1(p);
    }

    // returns the current points of the player
    int getPoints1() {
        return pointView.getPoints1();
    }
    
    // game over
    void gameOver() {
        if (gameOverFlag && gameOverFlag1){            
          addObject(new GameOverPage(getPoints(),getPoints1()), getWidth() / 2, getHeight() / 2);
          Greenfoot.stop();
        }  
   }

   
}
